@@ -33,8 +33,9 @@ def parse_url(url, warning=True):
 
     if warning and not is_download_link:
         warnings.warn(
-            "You specified Google Drive Link but it is not the correct link "
-            "to download the file. Maybe you should try: {url}".format(
+            "You specified a Google Drive link that is not the correct link "
+            "to download a file. You might want to try `--fuzzy` option "
+            "or the following url: {url}".format(
                 url="https://drive.google.com/uc?id={}".format(file_id)
             )
         )
